@@ -4,11 +4,11 @@ import sys
 from io import StringIO
 from itertools import product
 
-from .keylib import KeyNotFound
 from .exceptions import (
     ParserException,
     OutputException,
 )
+from .keylib import KeyNotFound
 from .urlhandling import get_contents
 
 
@@ -140,10 +140,22 @@ class Host(Section):
             lines.append(ConfigOutput.to_line(keyword, parts, indent=4))
         return lines
 
-    def apply_substitutions(self, lines, val_dict):
+    def apply_substitutions(self, lines, val_dict, expect_val=False):
         for line in lines:
+            original_line = line
             for subst, value in val_dict.items():
                 line = line.replace(subst, value)
+            if (
+                original_line
+                and expect_val
+                and line == original_line
+                and line.startswith("<")
+                and line.endswith(">")
+            ):
+                raise ParserException(
+                    "expected a value for variable '%s', set it using @set or @args"
+                    % original_line
+                )
             yield line
 
     def variable_iter(self, base):
@@ -168,7 +180,9 @@ class Host(Section):
         """
         defn_lines = self.resolve_defn(config_access)
         for val_dict in self.variable_iter(config_access.get_variables()):
-            subst = list(self.apply_substitutions(defn_lines, val_dict))
+            subst = list(
+                self.apply_substitutions(defn_lines, val_dict, expect_val=True)
+            )
             host = subst[0]
             lines = [ConfigOutput.to_line("Host", [host])] + subst[1:]
             yield host, lines
@@ -332,7 +346,7 @@ class SedgeEngine:
     def parse(self, fd):
         """very simple parser - but why would we want it to be complex?"""
 
-        def resolve_args(args):
+        def resolve_args(args, expect_val=False):
             # FIXME break this out, it's in common with the templating stuff elsewhere
             root = self.sections[0]
             val_dict = dict(
@@ -340,8 +354,20 @@ class SedgeEngine:
             )
             resolved_args = []
             for arg in args:
+                original_arg = arg
                 for subst, value in val_dict.items():
                     arg = arg.replace(subst, value)
+                if (
+                    original_arg
+                    and expect_val
+                    and arg == original_arg
+                    and arg.startswith("<")
+                    and arg.endswith(">")
+                ):
+                    raise ParserException(
+                        "expected a value for variable '%s', set it using @set or @args"
+                        % original_arg
+                    )
                 resolved_args.append(arg)
             return resolved_args
 
@@ -422,7 +448,7 @@ class SedgeEngine:
                 StringIO(contents),
                 self._verify_ssl,
                 url=url,
-                args=resolve_args(subargs),
+                args=resolve_args(subargs, expect_val=True),
                 parent_keydefs=self.keydefs,
                 via_include=True,
             )
